@@ -1,20 +1,19 @@
-import inspect
 import functools
-import warnings
-from distutils.version import LooseVersion
-
+import inspect
 import uuid
+import warnings
+
 import marshmallow as ma
-from marshmallow import validate, fields
-from sqlalchemy.dialects import postgresql, mysql, mssql
-from sqlalchemy.orm import SynonymProperty
 import sqlalchemy as sa
+from marshmallow import fields, validate
+from packaging.version import Version
+from sqlalchemy.dialects import mssql, mysql, postgresql
+from sqlalchemy.orm import SynonymProperty
 
 from .exceptions import ModelConversionError
 from .fields import Related, RelatedList
 
-
-_META_KWARGS_DEPRECATED = LooseVersion(ma.__version__) >= LooseVersion("3.10.0")
+_META_KWARGS_DEPRECATED = Version(ma.__version__) >= Version("3.10.0")
 
 
 def _is_field(value):
@@ -132,7 +131,8 @@ class ModelConverter:
     ):
         result = dict_cls()
         base_fields = base_fields or {}
-        for prop in model.__mapper__.iterate_properties:
+
+        for prop in model.__mapper__.attrs:
             key = self._get_field_name(prop)
             if self._should_exclude_field(prop, fields=fields, exclude=exclude):
                 # Allow marshmallow to validate and exclude the field key.
@@ -225,7 +225,7 @@ class ModelConverter:
             target_model = attr.target_class
             prop_name = attr.value_attr
             remote_with_local_multiplicity = attr.local_attr.prop.uselist
-        prop = target_model.__mapper__.get_property(prop_name)
+        prop = target_model.__mapper__.attrs.get(prop_name)
         converted_prop = self.property2field(prop, **kwargs)
         if remote_with_local_multiplicity:
             related_list_kwargs = _field_update_kwargs(
@@ -301,6 +301,7 @@ class ModelConverter:
                 'Passing `info={"marshmallow": ...}` is deprecated. '
                 "Use `SQLAlchemySchema` and `auto_field` instead.",
                 DeprecationWarning,
+                stacklevel=2,
             )
             validate = overrides.pop("validate", [])
             kwargs["validate"] = self._merge_validators(
